# Pluggable Apps

As discussed in [](./why), `viewdom_wired` is aimed at pluggable apps.
That document briefly explains what the means and why it matters.
Let's take a closer look.

- Brief statement
- Scenario
- Extending (the most common thing)
- Registering
- Replacing/customizing
- Caller/Callee conundrum
- Huge surface areas: learning, forking
